@@ -47,6 +47,7 @@ pub mod no_empty_pattern;
 pub mod no_eval;
 pub mod no_ex_assign;
 pub mod no_explicit_any;
+pub mod no_external_imports;
 pub mod no_extra_boolean_cast;
 pub mod no_extra_non_null_assertion;
 pub mod no_extra_semi;
@@ -272,6 +273,7 @@ fn get_all_rules_raw() -> Vec<Arc<dyn LintRule>> {
     no_eval::NoEval::new(),
     no_ex_assign::NoExAssign::new(),
     no_explicit_any::NoExplicitAny::new(),
+    no_external_imports::NoExternalImport::new(),
     no_extra_boolean_cast::NoExtraBooleanCast::new(),
     no_extra_non_null_assertion::NoExtraNonNullAssertion::new(),
     no_extra_semi::NoExtraSemi::new(),
